Package {futureverse}


Title: Install 'Futureverse' in One Go
Version: 0.3.0
Imports: future, futurize, future.apply, furrr, doFuture, progressify, progressr
Suggests: future.batchtools, future.callr, future.mirai, RhpcBLASctl
Description: The 'Futureverse' is a set of packages for parallel and distributed processing with the 'future' package at its core (Bengtsson, 2021, <doi:10.32614/RJ-2021-048>). Another notable component is the 'futurize' package (Bengtsson, 2026, <doi:10.48550/arXiv.2601.17578>) for turning common sequential calls into parallel ones via a single function futurize(). Similarly, the progressify() of the 'progressify' package makes common calls to report of progress. This package is designed to make it easy to install common 'Futureverse' packages in a single step. This package is intended for end-users, interactive use, and R scripts. Packages must not list it as a dependency - instead, explicitly declare each 'Futureverse' package as a dependency as needed.
URL: https://www.futureverse.org, https://github.com/futureverse/futureverse/
BugReports: https://github.com/futureverse/futureverse/issues
License: MIT + file LICENSE
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-04 15:44:19 UTC; hb
Author: Henrik Bengtsson ORCID iD [aut, cre, cph]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2026-07-04 16:00:02 UTC

futureverse: Install 'Futureverse' in One Go

Description

logo

The 'Futureverse' is a set of packages for parallel and distributed processing with the 'future' package at its core (Bengtsson, 2021, doi:10.32614/RJ-2021-048). Another notable component is the 'futurize' package (Bengtsson, 2026, doi:10.48550/arXiv.2601.17578) for turning common sequential calls into parallel ones via a single function futurize(). Similarly, the progressify() of the 'progressify' package makes common calls to report of progress. This package is designed to make it easy to install common 'Futureverse' packages in a single step. This package is intended for end-users, interactive use, and R scripts. Packages must not list it as a dependency - instead, explicitly declare each 'Futureverse' package as a dependency as needed.

Author(s)

Maintainer: Henrik Bengtsson henrikb@braju.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


List all Futureverse dependencies

Description

List all Futureverse dependencies

Usage

futureverse_deps(recursive = FALSE, repos = getOption("repos"))

Arguments

recursive

If TRUE, will also list all dependencies of Futureverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").

Value

A base::data.frame with columns package, cran, local, and behind.


List all packages in the Futureverse

Description

List all packages in the Futureverse

Usage

futureverse_packages(include_self = TRUE)

Arguments

include_self

Include futureverse in the list?

Value

Returns a character vector of package names.

Examples

futureverse_packages()


Update Futureverse packages

Description

This will check to see if all Futureverse packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.

Usage

futureverse_update(recursive = FALSE, repos = getOption("repos"))

Arguments

recursive

If TRUE, will also list all dependencies of Futureverse packages.

repos

The repositories to use to check for updates. Defaults to getOption("repos").

Value

Returns nothing; outputs installation instructions, if needed.

Examples

## Not run: 
futureverse_update()

## End(Not run)

mirror server hosted at Truenetwork, Russian Federation.